============
Installation
============

Permission-manager can be installed from PyPI:

.. code-block:: bash

    $ pip install permission-manager


Requirements
~~~~~~~~~~~~

Permission-manager requires Python >= 3.10 versions.
